# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`dhcp`](#dhcp): Manage an ISC DHCP server
* [`dhcp::disable`](#dhcp--disable): Remove and Disable the DHCP server
* [`dhcp::failover`](#dhcp--failover): Manage a DHCP failover config

#### Private Classes

* `dhcp::params`: Parameter defaults

### Defined types

* [`dhcp::dhcp_class`](#dhcp--dhcp_class): Manage a DHCP class in the config
* [`dhcp::host`](#dhcp--host): Manage a DHCP host
* [`dhcp::ignoredsubnet`](#dhcp--ignoredsubnet): Manage an ignored subnet
* [`dhcp::pool`](#dhcp--pool): Define a dhcp-pool for IPv4 networks
* [`dhcp::pool6`](#dhcp--pool6): Define a dhcp-pool for IPv6 networks
* [`dhcp::sharednetwork`](#dhcp--sharednetwork): defines a sharednetwork-segment to wrap several pools together

### Data types

* [`Dhcp::Mac`](#Dhcp--Mac)
* [`Dhcp::Syslogfacility`](#Dhcp--Syslogfacility)

## Classes

### <a name="dhcp"></a>`dhcp`

Manage an ISC DHCP server

#### Parameters

The following parameters are available in the `dhcp` class:

* [`dnsdomain`](#-dhcp--dnsdomain)
* [`nameservers`](#-dhcp--nameservers)
* [`nameservers_ipv6`](#-dhcp--nameservers_ipv6)
* [`ntpservers`](#-dhcp--ntpservers)
* [`dnssearchdomains`](#-dhcp--dnssearchdomains)
* [`dhcp_conf_header`](#-dhcp--dhcp_conf_header)
* [`dhcp_conf_ddns`](#-dhcp--dhcp_conf_ddns)
* [`dhcp_conf_ntp`](#-dhcp--dhcp_conf_ntp)
* [`dhcp_conf_pxe`](#-dhcp--dhcp_conf_pxe)
* [`dhcp_conf_extra`](#-dhcp--dhcp_conf_extra)
* [`dhcp_conf_fragments`](#-dhcp--dhcp_conf_fragments)
* [`interfaces`](#-dhcp--interfaces)
* [`interface`](#-dhcp--interface)
* [`dnsupdatekey`](#-dhcp--dnsupdatekey)
* [`ddns_update_style`](#-dhcp--ddns_update_style)
* [`dnskeyname`](#-dhcp--dnskeyname)
* [`ddns_update_static`](#-dhcp--ddns_update_static)
* [`ddns_update_optimize`](#-dhcp--ddns_update_optimize)
* [`ddns_client_updates`](#-dhcp--ddns_client_updates)
* [`pxeserver`](#-dhcp--pxeserver)
* [`pxefilename`](#-dhcp--pxefilename)
* [`mtu`](#-dhcp--mtu)
* [`ipxe_filename`](#-dhcp--ipxe_filename)
* [`ipxe_bootstrap`](#-dhcp--ipxe_bootstrap)
* [`logfacility`](#-dhcp--logfacility)
* [`default_lease_time`](#-dhcp--default_lease_time)
* [`max_lease_time`](#-dhcp--max_lease_time)
* [`service_ensure`](#-dhcp--service_ensure)
* [`globaloptions`](#-dhcp--globaloptions)
* [`omapi_port`](#-dhcp--omapi_port)
* [`omapi_name`](#-dhcp--omapi_name)
* [`omapi_algorithm`](#-dhcp--omapi_algorithm)
* [`omapi_key`](#-dhcp--omapi_key)
* [`authoritative`](#-dhcp--authoritative)
* [`extra_config`](#-dhcp--extra_config)
* [`dhcp_dir`](#-dhcp--dhcp_dir)
* [`dhcpd_conf_filename`](#-dhcp--dhcpd_conf_filename)
* [`packagename`](#-dhcp--packagename)
* [`manage_package`](#-dhcp--manage_package)
* [`servicename`](#-dhcp--servicename)
* [`manage_service`](#-dhcp--manage_service)
* [`package_provider`](#-dhcp--package_provider)
* [`ldap_port`](#-dhcp--ldap_port)
* [`ldap_server`](#-dhcp--ldap_server)
* [`ldap_username`](#-dhcp--ldap_username)
* [`ldap_password`](#-dhcp--ldap_password)
* [`ldap_base_dn`](#-dhcp--ldap_base_dn)
* [`ldap_method`](#-dhcp--ldap_method)
* [`ldap_debug_file`](#-dhcp--ldap_debug_file)
* [`use_ldap`](#-dhcp--use_ldap)
* [`option_code150_label`](#-dhcp--option_code150_label)
* [`option_code150_value`](#-dhcp--option_code150_value)
* [`dhcp_classes`](#-dhcp--dhcp_classes)
* [`hosts`](#-dhcp--hosts)
* [`ignoredsubnets`](#-dhcp--ignoredsubnets)
* [`pools`](#-dhcp--pools)
* [`pools6`](#-dhcp--pools6)
* [`sharednetworks`](#-dhcp--sharednetworks)
* [`on_commit`](#-dhcp--on_commit)
* [`on_release`](#-dhcp--on_release)
* [`on_expiry`](#-dhcp--on_expiry)
* [`dhcpd_binary`](#-dhcp--dhcpd_binary)

##### <a name="-dhcp--dnsdomain"></a>`dnsdomain`

Data type: `Optional[Array[String[1]]]`



Default value: `undef`

##### <a name="-dhcp--nameservers"></a>`nameservers`

Data type: `Array[Stdlib::IP::Address::V4]`



Default value: `[]`

##### <a name="-dhcp--nameservers_ipv6"></a>`nameservers_ipv6`

Data type: `Array[Stdlib::IP::Address::V6]`



Default value: `[]`

##### <a name="-dhcp--ntpservers"></a>`ntpservers`

Data type: `Array[Variant[Stdlib::Fqdn,Stdlib::IP::Address]]`



Default value: `[]`

##### <a name="-dhcp--dnssearchdomains"></a>`dnssearchdomains`

Data type: `Array[String[1]]`



Default value: `[]`

##### <a name="-dhcp--dhcp_conf_header"></a>`dhcp_conf_header`

Data type: `String`



Default value: `'INTERNAL_TEMPLATE'`

##### <a name="-dhcp--dhcp_conf_ddns"></a>`dhcp_conf_ddns`

Data type: `String`



Default value: `'INTERNAL_TEMPLATE'`

##### <a name="-dhcp--dhcp_conf_ntp"></a>`dhcp_conf_ntp`

Data type: `String`



Default value: `'INTERNAL_TEMPLATE'`

##### <a name="-dhcp--dhcp_conf_pxe"></a>`dhcp_conf_pxe`

Data type: `String`



Default value: `'INTERNAL_TEMPLATE'`

##### <a name="-dhcp--dhcp_conf_extra"></a>`dhcp_conf_extra`

Data type: `String`



Default value: `'INTERNAL_TEMPLATE'`

##### <a name="-dhcp--dhcp_conf_fragments"></a>`dhcp_conf_fragments`

Data type: `Hash[String[1], Hash[String[1], String[1]]]`



Default value: `{}`

##### <a name="-dhcp--interfaces"></a>`interfaces`

Data type: `Optional[Array[String[1]]]`



Default value: `undef`

##### <a name="-dhcp--interface"></a>`interface`

Data type: `String[1]`



Default value: `'NOTSET'`

##### <a name="-dhcp--dnsupdatekey"></a>`dnsupdatekey`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-dhcp--ddns_update_style"></a>`ddns_update_style`

Data type: `String[1]`



Default value: `'interim'`

##### <a name="-dhcp--dnskeyname"></a>`dnskeyname`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-dhcp--ddns_update_static"></a>`ddns_update_static`

Data type: `String[1]`



Default value: `'on'`

##### <a name="-dhcp--ddns_update_optimize"></a>`ddns_update_optimize`

Data type: `String[1]`



Default value: `'on'`

##### <a name="-dhcp--ddns_client_updates"></a>`ddns_client_updates`

Data type: `Enum['allow', 'deny']`



Default value: `'allow'`

##### <a name="-dhcp--pxeserver"></a>`pxeserver`

Data type: `Optional[Stdlib::Host]`



Default value: `undef`

##### <a name="-dhcp--pxefilename"></a>`pxefilename`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-dhcp--mtu"></a>`mtu`

Data type: `Optional[Integer[1]]`



Default value: `undef`

##### <a name="-dhcp--ipxe_filename"></a>`ipxe_filename`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-dhcp--ipxe_bootstrap"></a>`ipxe_bootstrap`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-dhcp--logfacility"></a>`logfacility`

Data type: `Dhcp::Syslogfacility`



Default value: `'daemon'`

##### <a name="-dhcp--default_lease_time"></a>`default_lease_time`

Data type: `Integer[-1]`



Default value: `43200`

##### <a name="-dhcp--max_lease_time"></a>`max_lease_time`

Data type: `Integer[-1]`



Default value: `86400`

##### <a name="-dhcp--service_ensure"></a>`service_ensure`

Data type: `Stdlib::Ensure::Service`



Default value: `'running'`

##### <a name="-dhcp--globaloptions"></a>`globaloptions`

Data type: `Optional[Variant[String,Array[String[1]]]]`



Default value: `undef`

##### <a name="-dhcp--omapi_port"></a>`omapi_port`

Data type: `Optional[Stdlib::Port]`



Default value: `undef`

##### <a name="-dhcp--omapi_name"></a>`omapi_name`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-dhcp--omapi_algorithm"></a>`omapi_algorithm`

Data type: `String[1]`



Default value: `'HMAC-MD5'`

##### <a name="-dhcp--omapi_key"></a>`omapi_key`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-dhcp--authoritative"></a>`authoritative`

Data type: `Boolean`



Default value: `true`

##### <a name="-dhcp--extra_config"></a>`extra_config`

Data type: `Variant[Array[String[1]],String[1]]`



Default value: `[]`

##### <a name="-dhcp--dhcp_dir"></a>`dhcp_dir`

Data type: `Stdlib::Absolutepath`



Default value: `$dhcp::params::dhcp_dir`

##### <a name="-dhcp--dhcpd_conf_filename"></a>`dhcpd_conf_filename`

Data type: `String[1]`



Default value: `'dhcpd.conf'`

##### <a name="-dhcp--packagename"></a>`packagename`

Data type: `String[1]`



Default value: `$dhcp::params::packagename`

##### <a name="-dhcp--manage_package"></a>`manage_package`

Data type: `Boolean`



Default value: `true`

##### <a name="-dhcp--servicename"></a>`servicename`

Data type: `Variant[String[1],Array[String[1]]]`



Default value: `$dhcp::params::servicename`

##### <a name="-dhcp--manage_service"></a>`manage_service`

Data type: `Boolean`



Default value: `true`

##### <a name="-dhcp--package_provider"></a>`package_provider`

Data type: `Optional[String[1]]`



Default value: `$dhcp::params::package_provider`

##### <a name="-dhcp--ldap_port"></a>`ldap_port`

Data type: `Stdlib::Port`



Default value: `389`

##### <a name="-dhcp--ldap_server"></a>`ldap_server`

Data type: `String[1]`



Default value: `'localhost'`

##### <a name="-dhcp--ldap_username"></a>`ldap_username`

Data type: `String[1]`



Default value: `'cn=root, dc=example, dc=com'`

##### <a name="-dhcp--ldap_password"></a>`ldap_password`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-dhcp--ldap_base_dn"></a>`ldap_base_dn`

Data type: `String[1]`



Default value: `'dc=example, dc=com'`

##### <a name="-dhcp--ldap_method"></a>`ldap_method`

Data type: `Enum['dynamic', 'static']`



Default value: `'dynamic'`

##### <a name="-dhcp--ldap_debug_file"></a>`ldap_debug_file`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: `undef`

##### <a name="-dhcp--use_ldap"></a>`use_ldap`

Data type: `Boolean`



Default value: `false`

##### <a name="-dhcp--option_code150_label"></a>`option_code150_label`

Data type: `String[1]`



Default value: `'pxegrub'`

##### <a name="-dhcp--option_code150_value"></a>`option_code150_value`

Data type: `String[1]`



Default value: `'text'`

##### <a name="-dhcp--dhcp_classes"></a>`dhcp_classes`

Data type: `Hash[String[1], Hash]`



Default value: `{}`

##### <a name="-dhcp--hosts"></a>`hosts`

Data type: `Hash[String[1], Hash]`



Default value: `{}`

##### <a name="-dhcp--ignoredsubnets"></a>`ignoredsubnets`

Data type: `Hash[String, Hash]`



Default value: `{}`

##### <a name="-dhcp--pools"></a>`pools`

Data type: `Hash[String, Hash]`



Default value: `{}`

##### <a name="-dhcp--pools6"></a>`pools6`

Data type: `Hash[String, Hash]`



Default value: `{}`

##### <a name="-dhcp--sharednetworks"></a>`sharednetworks`

Data type: `Hash[String, Hash]`



Default value: `{}`

##### <a name="-dhcp--on_commit"></a>`on_commit`

Data type: `Array[String[1]]`



Default value: `[]`

##### <a name="-dhcp--on_release"></a>`on_release`

Data type: `Array[String[1]]`



Default value: `[]`

##### <a name="-dhcp--on_expiry"></a>`on_expiry`

Data type: `Array[String[1]]`



Default value: `[]`

##### <a name="-dhcp--dhcpd_binary"></a>`dhcpd_binary`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: `$dhcp::params::dhcpd_binary`

### <a name="dhcp--disable"></a>`dhcp::disable`

Remove and Disable the DHCP server

#### Parameters

The following parameters are available in the `dhcp::disable` class:

* [`packagename`](#-dhcp--disable--packagename)
* [`servicename`](#-dhcp--disable--servicename)

##### <a name="-dhcp--disable--packagename"></a>`packagename`

Data type: `String[1]`



Default value: `$dhcp::params::packagename`

##### <a name="-dhcp--disable--servicename"></a>`servicename`

Data type: `String[1]`



Default value: `$dhcp::params::servicename`

### <a name="dhcp--failover"></a>`dhcp::failover`

Manage a DHCP failover config

#### Parameters

The following parameters are available in the `dhcp::failover` class:

* [`peer_address`](#-dhcp--failover--peer_address)
* [`role`](#-dhcp--failover--role)
* [`address`](#-dhcp--failover--address)
* [`port`](#-dhcp--failover--port)
* [`max_response_delay`](#-dhcp--failover--max_response_delay)
* [`max_unacked_updates`](#-dhcp--failover--max_unacked_updates)
* [`mclt`](#-dhcp--failover--mclt)
* [`load_split`](#-dhcp--failover--load_split)
* [`load_balance`](#-dhcp--failover--load_balance)
* [`omapi_key`](#-dhcp--failover--omapi_key)
* [`dhcp_dir`](#-dhcp--failover--dhcp_dir)
* [`dhcpd_conf_filename`](#-dhcp--failover--dhcpd_conf_filename)

##### <a name="-dhcp--failover--peer_address"></a>`peer_address`

Data type: `Any`



##### <a name="-dhcp--failover--role"></a>`role`

Data type: `Any`



Default value: `'primary'`

##### <a name="-dhcp--failover--address"></a>`address`

Data type: `Any`



Default value: `$facts['networking']['ip']`

##### <a name="-dhcp--failover--port"></a>`port`

Data type: `Any`



Default value: `'519'`

##### <a name="-dhcp--failover--max_response_delay"></a>`max_response_delay`

Data type: `Any`



Default value: `'30'`

##### <a name="-dhcp--failover--max_unacked_updates"></a>`max_unacked_updates`

Data type: `Any`



Default value: `'10'`

##### <a name="-dhcp--failover--mclt"></a>`mclt`

Data type: `Any`



Default value: `'300'`

##### <a name="-dhcp--failover--load_split"></a>`load_split`

Data type: `Any`



Default value: `'128'`

##### <a name="-dhcp--failover--load_balance"></a>`load_balance`

Data type: `Any`



Default value: `'3'`

##### <a name="-dhcp--failover--omapi_key"></a>`omapi_key`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-dhcp--failover--dhcp_dir"></a>`dhcp_dir`

Data type: `Any`



Default value: `$dhcp::dhcp_dir`

##### <a name="-dhcp--failover--dhcpd_conf_filename"></a>`dhcpd_conf_filename`

Data type: `Any`



Default value: `$dhcp::dhcpd_conf_filename`

## Defined types

### <a name="dhcp--dhcp_class"></a>`dhcp::dhcp_class`

Manage a DHCP class in the config

#### Parameters

The following parameters are available in the `dhcp::dhcp_class` defined type:

* [`parameters`](#-dhcp--dhcp_class--parameters)

##### <a name="-dhcp--dhcp_class--parameters"></a>`parameters`

Data type: `Variant[Array[String[1]], String[1]]`



### <a name="dhcp--host"></a>`dhcp::host`

Manage a DHCP host

#### Parameters

The following parameters are available in the `dhcp::host` defined type:

* [`ip`](#-dhcp--host--ip)
* [`mac`](#-dhcp--host--mac)
* [`ddns_hostname`](#-dhcp--host--ddns_hostname)
* [`options`](#-dhcp--host--options)
* [`comment`](#-dhcp--host--comment)
* [`ignored`](#-dhcp--host--ignored)
* [`default_lease_time`](#-dhcp--host--default_lease_time)
* [`max_lease_time`](#-dhcp--host--max_lease_time)
* [`ipxe_filename`](#-dhcp--host--ipxe_filename)
* [`ipxe_bootstrap`](#-dhcp--host--ipxe_bootstrap)
* [`filename`](#-dhcp--host--filename)
* [`on_commit`](#-dhcp--host--on_commit)
* [`on_release`](#-dhcp--host--on_release)
* [`on_expiry`](#-dhcp--host--on_expiry)

##### <a name="-dhcp--host--ip"></a>`ip`

Data type: `Optional[Stdlib::IP::Address]`

The ip address of the DHCP host.

Default value: `undef`

##### <a name="-dhcp--host--mac"></a>`mac`

Data type: `Dhcp::Mac`

The MAC address.

##### <a name="-dhcp--host--ddns_hostname"></a>`ddns_hostname`

Data type: `String`

The name parameter should be the hostname that will be used in setting up the client's A and PTR records.
If no ddns-hostname is specified in scope, then the server will derive the hostname automatically, using an
algorithm that varies for each of the different update methods.

Default value: `$name`

##### <a name="-dhcp--host--options"></a>`options`

Data type: `Hash`

A hash with key value pairs to go to the option lines. The word 'option' is not needed.

Default value: `{}`

##### <a name="-dhcp--host--comment"></a>`comment`

Data type: `Optional[String[1]]`

A comment added to the DHCP host.

Default value: `undef`

##### <a name="-dhcp--host--ignored"></a>`ignored`

Data type: `Boolean`

If set to true results in `ignore booting;` line in the DHCP host configuration.

Default value: `false`

##### <a name="-dhcp--host--default_lease_time"></a>`default_lease_time`

Data type: `Optional[Integer]`

Default lease length.

Default value: `undef`

##### <a name="-dhcp--host--max_lease_time"></a>`max_lease_time`

Data type: `Optional[Integer]`

The maximum lease length.

Default value: `undef`

##### <a name="-dhcp--host--ipxe_filename"></a>`ipxe_filename`

Data type: `Optional[String[1]]`

The ipxe filenme, e. g. ipxe.efi.

Default value: `undef`

##### <a name="-dhcp--host--ipxe_bootstrap"></a>`ipxe_bootstrap`

Data type: `Optional[String[1]]`

The bootstrap file of UEFI PXE, e. g. winpe.ipxe

Default value: `undef`

##### <a name="-dhcp--host--filename"></a>`filename`

Data type: `Optional[String[1]]`

The file to be loaded by TFTP.

Default value: `undef`

##### <a name="-dhcp--host--on_commit"></a>`on_commit`

Data type: `Array[String[1]]`

An array with statements to go into the hook on commit.

Default value: `[]`

##### <a name="-dhcp--host--on_release"></a>`on_release`

Data type: `Array[String[1]]`

An array with statements to go into the hook on release.

Default value: `[]`

##### <a name="-dhcp--host--on_expiry"></a>`on_expiry`

Data type: `Array[String[1]]`

An array with statements to go into the hook on expiry.

Default value: `[]`

### <a name="dhcp--ignoredsubnet"></a>`dhcp::ignoredsubnet`

Manage an ignored subnet

#### Parameters

The following parameters are available in the `dhcp::ignoredsubnet` defined type:

* [`network`](#-dhcp--ignoredsubnet--network)
* [`mask`](#-dhcp--ignoredsubnet--mask)

##### <a name="-dhcp--ignoredsubnet--network"></a>`network`

Data type: `Any`



##### <a name="-dhcp--ignoredsubnet--mask"></a>`mask`

Data type: `Any`



### <a name="dhcp--pool"></a>`dhcp::pool`

Define a dhcp-pool for IPv4 networks

#### Parameters

The following parameters are available in the `dhcp::pool` defined type:

* [`network`](#-dhcp--pool--network)
* [`mask`](#-dhcp--pool--mask)
* [`host_mask`](#-dhcp--pool--host_mask)
* [`gateway`](#-dhcp--pool--gateway)
* [`range`](#-dhcp--pool--range)
* [`failover`](#-dhcp--pool--failover)
* [`options`](#-dhcp--pool--options)
* [`parameters`](#-dhcp--pool--parameters)
* [`sharednetwork`](#-dhcp--pool--sharednetwork)
* [`nameservers`](#-dhcp--pool--nameservers)
* [`nameservers_ipv6`](#-dhcp--pool--nameservers_ipv6)
* [`pxeserver`](#-dhcp--pool--pxeserver)
* [`mtu`](#-dhcp--pool--mtu)
* [`domain_name`](#-dhcp--pool--domain_name)
* [`ignore_unknown`](#-dhcp--pool--ignore_unknown)
* [`on_commit`](#-dhcp--pool--on_commit)
* [`on_release`](#-dhcp--pool--on_release)
* [`on_expiry`](#-dhcp--pool--on_expiry)

##### <a name="-dhcp--pool--network"></a>`network`

Data type: `Stdlib::IP::Address::V4`

Base-IP-Address of the pool

##### <a name="-dhcp--pool--mask"></a>`mask`

Data type: `Stdlib::IP::Address::V4`

Networkmask of that pool

##### <a name="-dhcp--pool--host_mask"></a>`host_mask`

Data type: `Stdlib::IP::Address::V4`

Networkmask that is supplied to the client
Defaults to `mask`. Use it to supply a smaller
mask to clients if needed

Default value: `$mask`

##### <a name="-dhcp--pool--gateway"></a>`gateway`

Data type: `Optional[String[1]]`

Optional IP-address for the gateway

Default value: `undef`

##### <a name="-dhcp--pool--range"></a>`range`

Data type: `Optional[Variant[Array[String[1],1],String[1]]]`

Optional IP-range to supply addresses from
Specify as String with start- and end-IP-address
separated by space

Default value: `undef`

##### <a name="-dhcp--pool--failover"></a>`failover`

Data type: `Optional[String[1]]`

Optional name of the DHCP-server to failover

Default value: `undef`

##### <a name="-dhcp--pool--options"></a>`options`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Optional String or Array of `option` to set in the pool

Default value: `undef`

##### <a name="-dhcp--pool--parameters"></a>`parameters`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Optional String or Array of manual parameters to set

Default value: `undef`

##### <a name="-dhcp--pool--sharednetwork"></a>`sharednetwork`

Data type: `Optional[String[1]]`

Optional String to group this pool into a shared-network
segment by the name `sharednetwork`. You need to define
that segment by using `dhcp::sharednetwork`

Default value: `undef`

##### <a name="-dhcp--pool--nameservers"></a>`nameservers`

Data type: `Optional[Array[String]]`

Optional set of IPv4-nameservers to supply to the client

Default value: `undef`

##### <a name="-dhcp--pool--nameservers_ipv6"></a>`nameservers_ipv6`

Data type: `Optional[Array[String]]`

Optional set of IPv6-nameservers to supply to the client

Default value: `undef`

##### <a name="-dhcp--pool--pxeserver"></a>`pxeserver`

Data type: `Optional[String]`

Optional name of a PXE-server to boot from

Default value: `undef`

##### <a name="-dhcp--pool--mtu"></a>`mtu`

Data type: `Optional[Integer]`

Optional size of the MTU to supply to the client

Default value: `undef`

##### <a name="-dhcp--pool--domain_name"></a>`domain_name`

Data type: `Optional[String[1]]`

Optional domainname for the client

Default value: `undef`

##### <a name="-dhcp--pool--ignore_unknown"></a>`ignore_unknown`

Data type: `Any`

Set to true to disable leases for clients not
explicitly defined by `dhcp::host`

Default value: `undef`

##### <a name="-dhcp--pool--on_commit"></a>`on_commit`

Data type: `Array[String[1]]`

Set of statements to execute when providing a lease

Default value: `[]`

##### <a name="-dhcp--pool--on_release"></a>`on_release`

Data type: `Array[String[1]]`

Set of statements to execute when a lease is released

Default value: `[]`

##### <a name="-dhcp--pool--on_expiry"></a>`on_expiry`

Data type: `Array[String[1]]`

Set of statements to execute when a lease expires

Default value: `[]`

### <a name="dhcp--pool6"></a>`dhcp::pool6`

Define a dhcp-pool for IPv6 networks

#### Parameters

The following parameters are available in the `dhcp::pool6` defined type:

* [`network`](#-dhcp--pool6--network)
* [`prefix`](#-dhcp--pool6--prefix)
* [`range`](#-dhcp--pool6--range)
* [`range_temp`](#-dhcp--pool6--range_temp)
* [`failover`](#-dhcp--pool6--failover)
* [`options`](#-dhcp--pool6--options)
* [`parameters`](#-dhcp--pool6--parameters)
* [`sharednetwork`](#-dhcp--pool6--sharednetwork)
* [`nameservers`](#-dhcp--pool6--nameservers)
* [`nameservers_ipv6`](#-dhcp--pool6--nameservers_ipv6)
* [`pxeserver`](#-dhcp--pool6--pxeserver)
* [`mtu`](#-dhcp--pool6--mtu)
* [`domain_name`](#-dhcp--pool6--domain_name)
* [`ignore_unknown`](#-dhcp--pool6--ignore_unknown)
* [`on_commit`](#-dhcp--pool6--on_commit)
* [`on_release`](#-dhcp--pool6--on_release)
* [`on_expiry`](#-dhcp--pool6--on_expiry)

##### <a name="-dhcp--pool6--network"></a>`network`

Data type: `Stdlib::IP::Address::V6`



##### <a name="-dhcp--pool6--prefix"></a>`prefix`

Data type: `Integer`



##### <a name="-dhcp--pool6--range"></a>`range`

Data type: `Optional[Variant[Array[String[1],1],String[1]]]`



Default value: `undef`

##### <a name="-dhcp--pool6--range_temp"></a>`range_temp`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-dhcp--pool6--failover"></a>`failover`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-dhcp--pool6--options"></a>`options`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`



Default value: `undef`

##### <a name="-dhcp--pool6--parameters"></a>`parameters`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`



Default value: `undef`

##### <a name="-dhcp--pool6--sharednetwork"></a>`sharednetwork`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-dhcp--pool6--nameservers"></a>`nameservers`

Data type: `Optional[Array[String]]`



Default value: `undef`

##### <a name="-dhcp--pool6--nameservers_ipv6"></a>`nameservers_ipv6`

Data type: `Optional[Array[String]]`



Default value: `undef`

##### <a name="-dhcp--pool6--pxeserver"></a>`pxeserver`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-dhcp--pool6--mtu"></a>`mtu`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-dhcp--pool6--domain_name"></a>`domain_name`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-dhcp--pool6--ignore_unknown"></a>`ignore_unknown`

Data type: `Any`



Default value: `undef`

##### <a name="-dhcp--pool6--on_commit"></a>`on_commit`

Data type: `Array[String[1]]`



Default value: `[]`

##### <a name="-dhcp--pool6--on_release"></a>`on_release`

Data type: `Array[String[1]]`



Default value: `[]`

##### <a name="-dhcp--pool6--on_expiry"></a>`on_expiry`

Data type: `Array[String[1]]`



Default value: `[]`

### <a name="dhcp--sharednetwork"></a>`dhcp::sharednetwork`

defines a sharednetwork-segment to wrap several pools together

#### Parameters

The following parameters are available in the `dhcp::sharednetwork` defined type:

* [`sharednetwork`](#-dhcp--sharednetwork--sharednetwork)
* [`parameters`](#-dhcp--sharednetwork--parameters)

##### <a name="-dhcp--sharednetwork--sharednetwork"></a>`sharednetwork`

Data type: `String`

Name of the sharednetwork as used in `dhcp::pool` and `dhcp::pool6`
defaults to the title of this resource

Default value: `$title`

##### <a name="-dhcp--sharednetwork--parameters"></a>`parameters`

Data type: `Optional[Variant[Array[String[1]], String[1]]]`

optional defaults you can set for the shared-network
can be either a single parameter-string, or an array of
several parameters

Default value: `undef`

## Data types

### <a name="Dhcp--Mac"></a>`Dhcp::Mac`

The Dhcp::Mac data type.

Alias of `Pattern[/^[0-9A-Fa-f]{1,2}(:[0-9A-Fa-f]{1,2}){5}$/]`

### <a name="Dhcp--Syslogfacility"></a>`Dhcp::Syslogfacility`

The Dhcp::Syslogfacility data type.

Alias of `Enum['user', 'mail', 'daemon', 'auth', 'syslog', 'lpr', 'news', 'uucp', 'cron', 'authpriv', 'ftp', 'ntp', 'security', 'console', 'solaris-cron', 'local0', 'local1', 'local2', 'local3', 'local4', 'local5', 'local6', 'local7']`

